@@ -8,6 +8,6 @@ test_that("glmnet + predict() works", {
   model <- logistic_reg(penalty = 10, mixture = 0.1) %>%
     set_engine("glmnet") %>%
     fit(as.factor(vs) ~ ., data = mtcars)
-  axed <- axe_call(fit)
-  expect_equal(axed$call, rlang::expr(dummy_call()))
+  axed <- axe_call(model)
+  expect_equal(axed$fit$call, rlang::expr(dummy_call()))
 })
